@@ -33,9 +33,10 @@
 #  define KEDUVOCDOCUMENT_DEPRECATED_NO_EXPORT KEDUVOCDOCUMENT_NO_EXPORT KEDUVOCDOCUMENT_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KEDUVOCDOCUMENT_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KEDUVOCDOCUMENT_NO_DEPRECATED
+#    define KEDUVOCDOCUMENT_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
